@@ -4,6 +4,7 @@ import logging
 import os
 import re
 import shutil
+from datetime import datetime
 from pathlib import Path, PurePosixPath
 from subprocess import Popen, PIPE, STDOUT
 
@@ -11,6 +12,7 @@ from celery import Celery
 
 from render import RENDER_DIR
 import render.aws as aws
+from render.logger import configure_logger
 
 celery = Celery()
 celery.config_from_object('render.celeryconfig')
@@ -45,12 +47,12 @@ class FollowLog:
     def next(self):
         self.clear()
         self.next_handler = next(self.handlers)
-        print(f'Following pattern "{self.next_handler.pattern}"')
+        logger.info(f'Following pattern "{self.next_handler.pattern}"')
 
     def make_view_dir(self):
         directory = self.workdir / self.current_view
         directory.mkdir(exist_ok=True)
-        print(f"Created directory - {directory}")
+        logger.info(f"Created directory - {directory}")
 
     def move_files(self):
         assert self.current_view
@@ -60,7 +62,7 @@ class FollowLog:
             filename = os.path.basename(file)
             dst_filename = dest_directory / filename
             shutil.move(file, dst_filename)
-            print(f"File {filename} moved into {dest_directory}")
+            logger.info(f"File {filename} moved into {dest_directory}")
 
             yield dst_filename
 
@@ -114,7 +116,7 @@ class Render:
 
     def run(self, extension='exr'):
         self.client.download_file(self.scene, self.local_scene)
-        print(f"Scene downloaded - {self.local_scene}")
+        logger.info(f"Scene downloaded - {self.local_scene}")
         if not self.local_scene.is_file():
             raise Exception("Local file does not exists")
 
@@ -137,11 +139,29 @@ class Render:
                 self.task_id / 'result' / view / file.name,
                 file
             )
-            print(f"Artifact is uploaded - {file}")
+            logger.info(f"Artifact is uploaded - {file}")
         process.wait()
         return process.returncode
 
 
+def record_time(f):
+    def format_date(value: datetime):
+        return value.strftime('%H:%M %d:%m:%Y')
+
+    def wrapper(*args, **kwargs):
+        begin = datetime.now()
+        logger.info(f"Started: {format_date(begin)}")
+        try:
+            return f(*args, **kwargs)
+        finally:
+            end = datetime.now()
+            logger.info(f"Finished: {format_date(end)}")
+            logger.info(f"Took: {str(begin - end).split('.')[0]}")
+
+    return wrapper
+
+
+@record_time
 def _run(scene):
     s3 = aws.S3(
         os.environ['AWS_BUCKET'],
@@ -150,7 +170,8 @@ def _run(scene):
         endpoint_url=os.environ['AWS_ENDPOINT'],
     )
     render = Render(PurePosixPath(scene), client=s3)
-    rc = render.run()
+    configure_logger(render.workdir)  # should be before run
+    rc = record_time(render.run)()
     if rc > 0:
         raise Exception(f"3dsmax returned non zero code {rc}")
 
@@ -162,4 +183,5 @@ def run(scene):
     assert os.environ['AWS_SECRET_ACCESS_KEY'], "AWS_SECRET_ACCESS_KEY must be defined"
     assert os.environ['AWS_ENDPOINT'], "AWS_ENDPOINT must be defined"
     assert os.environ['AWS_BUCKET'], "AWS_BUCKET must be defined"
+    assert os.environ['LOG_DIR'], "LOG_DIR must be defined"
     return _run(scene)
